# Django Spire

![Build](https://img.shields.io/github/actions/workflow/status/stratusadv/django-spire/run_tests.yml)
![Python Versions](https://img.shields.io/pypi/pyversions/django-spire)
![PyPI Version](https://img.shields.io/pypi/v/django-spire)
![Downloads](https://img.shields.io/pypi/dm/django-spire)

## Purpose

Make Django application development modular, extensible, and configurable.

## Getting Started

Please refer to our [website](https://django-spire.stratusadv.com) for detailed setup, module configuration, and usage examples.

<p align="center">
    <a href="https://django-spire.stratusadv.com">
        <img alt="Dandy Logo" src="https://django-spire.stratusadv.com/static/img/django_spire_logo_512.png"/>
    </a>
</p>
